==> jc-1.4.0.tar.gz: javax/swing/plaf/BorderUIResource__24MatteBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$MatteBorderUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class a25a7c61707145e8 javax_swing_border_EmptyBorder
// @dep_class 42288a678fbab155 javax_swing_border_MatteBorder
// @dep_class be9783cb235eb786 javax_swing_plaf_BorderUIResource__24MatteBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_MatteBorder

#include "javax/swing/border/MatteBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$method$_init$09cf8b39ff9e131e(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object *, jint, jint, jint, jint, struct _jc_java_awt_Color$object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$method$_init$1c9d857ac16e3ebd(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object *, jint, jint, jint, jint, struct _jc_object *);
extern void _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$method$_init$0fd162b98f069aeb(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EmptyBorder$vmethods	javax_swing_border_EmptyBorder;
	_jc_javax_swing_border_MatteBorder$vmethods	javax_swing_border_MatteBorder;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24MatteBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24MatteBorderUIResource;
    _jc_javax_swing_border_MatteBorder$sub_refs	javax_swing_border_MatteBorder;
    _jc_javax_swing_border_EmptyBorder$sub_refs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EmptyBorder$sub_nonrefs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_MatteBorder$sub_nonrefs	javax_swing_border_MatteBorder;
    _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24MatteBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24MatteBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/BorderUIResource__24MatteBorderUIResource.h <==
// public class javax.swing.plaf.BorderUIResource$MatteBorderUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class a25a7c61707145e8 javax_swing_border_EmptyBorder
// @dep_class 42288a678fbab155 javax_swing_border_MatteBorder
// @dep_class be9783cb235eb786 javax_swing_plaf_BorderUIResource__24MatteBorderUIResource

// header file dependencies
// @dep_header javax_swing_border_MatteBorder

#include "javax/swing/border/MatteBorder.h"

#ifndef _JC_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource_H_
#define _JC_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object;

typedef struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$fields_struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$method$_init$09cf8b39ff9e131e(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object *, jint, jint, jint, jint, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$method$_init$1c9d857ac16e3ebd(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object *, jint, jint, jint, jint, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$method$_init$0fd162b98f069aeb(_jc_env *, struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_border_EmptyBorder$vmethods	javax_swing_border_EmptyBorder;
	_jc_javax_swing_border_MatteBorder$vmethods	javax_swing_border_MatteBorder;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vmethods	javax_swing_plaf_BorderUIResource__24MatteBorderUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs {
    _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_refs	javax_swing_plaf_BorderUIResource__24MatteBorderUIResource;
    _jc_javax_swing_border_MatteBorder$sub_refs	javax_swing_border_MatteBorder;
    _jc_javax_swing_border_EmptyBorder$sub_refs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_border_EmptyBorder$sub_nonrefs	javax_swing_border_EmptyBorder;
    _jc_javax_swing_border_MatteBorder$sub_nonrefs	javax_swing_border_MatteBorder;
    _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$sub_nonrefs	javax_swing_plaf_BorderUIResource__24MatteBorderUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$object {
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$vtype _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_BorderUIResource__24MatteBorderUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_BorderUIResource__24MatteBorderUIResource_H_ */
